import * as i0 from '@angular/core';
import { Injectable, Component, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

class NgToastService {
    constructor() {
        this.toastDetails$ = new Subject();
    }
    getToastDetails() {
        return this.toastDetails$.asObservable();
    }
    success(message) {
        this.toastDetails$.next({ type: 'success', detail: message.detail, position: message.position, summary: message.summary, duration: message.duration, sticky: message.sticky });
    }
    error(message) {
        this.toastDetails$.next({ type: 'error', detail: message.detail, position: message.position, summary: message.summary, duration: message.duration, sticky: message.sticky });
    }
    info(message) {
        this.toastDetails$.next({ type: 'info', detail: message.detail, position: message.position, summary: message.summary, duration: message.duration, sticky: message.sticky });
    }
    warning(message) {
        this.toastDetails$.next({ type: 'warning', detail: message.detail, summary: message.summary, position: message.position, duration: message.duration, sticky: message.sticky });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class NgToastComponent {
    constructor(toastService) {
        this.toastService = toastService;
        this.show = false;
    }
    ngOnInit() {
        this.toastService.getToastDetails().subscribe((val) => {
            this.show = true;
            clearTimeout(this.timeoutRef);
            this.toastDetails = val;
            if (this.toastDetails.duration) {
                this.timeoutRef = setTimeout(() => {
                    this.show = false;
                }, this.toastDetails.duration);
            }
            if (this.toastDetails.sticky) { // for sticky
                clearTimeout(this.timeoutRef);
                this.show = true;
            }
            if (!this.toastDetails.duration && !this.toastDetails.sticky) { //no duration and sticky is true
                this.timeoutRef = setTimeout(() => {
                    this.show = false;
                }, 5000);
            }
        });
    }
    closeToast() {
        clearTimeout(this.timeoutRef);
        this.show = false;
    }
    loadPosition() {
        let postionClass = "";
        if (this.toastDetails?.position !== undefined) {
            switch (this.toastDetails.position) {
                case "tr":
                    postionClass = 'toast-top-right';
                    break;
                case "tl":
                    postionClass = 'toast-top-left';
                    break;
                case "br":
                    postionClass = 'toast-bottom-right';
                    break;
                case "bl":
                    postionClass = 'toast-bottom-left';
                    break;
                case "tc":
                    postionClass = 'toast-top-center';
                    break;
                case "bc":
                    postionClass = 'toast-bottom-center';
                    break;
                default: postionClass = "toast-top-right";
            }
        }
        else {
            postionClass = "toast-top-right";
        }
        if (this.toastDetails?.type !== undefined) {
            switch (this.toastDetails.type) {
                case "success":
                    postionClass = postionClass + " success";
                    break;
                case "error":
                    postionClass = postionClass + " error";
                    break;
                case "info":
                    postionClass = postionClass + " info";
                    break;
                case "warning":
                    postionClass = postionClass + " warning";
                    break;
                default: postionClass = "toast-right-top";
            }
        }
        return postionClass;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastComponent, deps: [{ token: NgToastService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.1", type: NgToastComponent, selector: "lib-ng-toast", ngImport: i0, template: "<!-- <div class=\"toast-container\">\n  <div [ngClass]=\"loadPosition()\" [class.active]=\"show\">\n    <div class=\"container-1\">\n      <i class=\"fa\" [ngClass]=\"{\n        'fa-times-circle': toastDetails?.type === 'error',\n        'fa-check-circle': toastDetails?.type === 'success',\n        'fa-exclamation-circle': toastDetails?.type === 'warning',\n        'fa-info-circle': toastDetails?.type === 'info'\n      }\"></i>\n    </div>\n    <div class=\"container-2\">\n      <p>{{ toastDetails?.detail }}</p>\n      <p>{{ toastDetails?.summary }}</p>\n    </div>\n    <button *ngIf=\"show\" id=\"close\" (click)=\"closeToast()\">&times;</button>\n  </div>\n</div> -->\n\n<div class=\"toast-container\" [ngClass]=\"{\n            'toast-top-center': toastDetails?.position === 'tc',\n            'toast-top-left': toastDetails?.position === 'tl',\n            'toast-top-right': toastDetails?.position === 'tr',\n            'toast-bottom-left': toastDetails?.position === 'bl',\n            'toast-bottom-right': toastDetails?.position === 'br',\n            'toast-bottom-center': toastDetails?.position === 'bc'\n          }\" [class.active]=\"show\"\n          [class.toast-top-right]=\"toastDetails?.position === (null || undefined || '')\">\n  <div class=\"ng-toast\" [ngClass]=\"{\n            'error': toastDetails?.type === 'error',\n            'success': toastDetails?.type === 'success',\n            'warning': toastDetails?.type === 'warning',\n            'info': toastDetails?.type === 'info'\n          }\">\n    <div class=\"container-1\">\n      <i class=\"fa\" [ngClass]=\"{\n            'fa-times-circle': toastDetails?.type === 'error',\n            'fa-check-circle': toastDetails?.type === 'success',\n            'fa-exclamation-circle': toastDetails?.type === 'warning',\n            'fa-info-circle': toastDetails?.type === 'info'\n          }\"></i>\n    </div>\n    <div class=\"container-2\">\n      <p>{{ toastDetails?.detail }}</p>\n      <p>{{ toastDetails?.summary }}</p>\n    </div>\n    <button *ngIf=\"show\" id=\"close\" (click)=\"closeToast()\">&times;</button>\n  </div>\n</div>\n", styles: ["*{padding:0;margin:0;box-sizing:border-box;border:none}.show-toast{margin:10px;background-color:#101020;color:#fff;padding:20px;border-radius:5px;cursor:pointer}.fa-times-circle{color:#ff355b}.fa-check-circle{color:#47d764}.fa-exclamation-circle{color:#ffc021}.fa-info-circle{color:#2f86eb}.container-1{margin:7px 0 7px 7px;display:flex}.container-1 i{font-size:30px}.container-2{display:flex;flex-direction:column;margin-left:4px;font-family:roboto,sans-serif}.container-2 p:first-child{display:flex;flex-direction:column;margin-left:5px;font-size:.9rem;font-family:roboto,sans-serif}.container-2 p:last-child{font-size:14px;color:#656565;font-weight:400;font-family:roboto,sans-serif;margin-left:5px}#close{align-self:flex-start;background-color:transparent;font-size:25px;line-height:0;color:#656565;cursor:pointer}.toast-container{pointer-events:none;position:fixed;z-index:999999;transition:.5s}.toast-top-center{top:5%;right:0;width:100%;transform:translateY(-400px)}.toast-top-center.active{transform:translate(0)}.toast-bottom-center{bottom:5%;right:0;width:100%;transform:translateY(400px)}.toast-bottom-center.active{transform:translate(0)}.toast-top-right{right:1%;top:5%;transform:translate(400px)}.toast-top-right.active{transform:translate(0)}.toast-bottom-right{right:1%;bottom:5%;transform:translate(400px)}.toast-bottom-right.active{transform:translate(0)}.toast-top-left{left:1%;top:5%;transform:translate(-400px)}.toast-top-left.active{transform:translate(0)}.toast-bottom-left{left:1%;bottom:5%;transform:translate(-400px)}.toast-bottom-left.active{transform:translate(0)}.toast-container.toast-top-center .ng-toast,.toast-container.toast-bottom-center .ng-toast{width:350px;margin-left:auto;margin-right:auto}.ng-toast{width:350px;height:auto;font-size:1rem;padding:10px;box-shadow:0 10px 20px #4b32320d;border-radius:7px;display:grid;grid-template-columns:1.2fr 6fr .5fr;transition:.5s;pointer-events:auto}.ng-toast.error{border-left:8px solid #ff355b;background-color:#ffe7e6}.ng-toast.warning{border-left:8px solid #ffc021;background-color:#fff2e2}.ng-toast.success{border-left:8px solid #47d764;background-color:#e4f8f0}.ng-toast.info{border-left:8px solid #2f86eb;background-color:#e9e9ff}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ng-toast', template: "<!-- <div class=\"toast-container\">\n  <div [ngClass]=\"loadPosition()\" [class.active]=\"show\">\n    <div class=\"container-1\">\n      <i class=\"fa\" [ngClass]=\"{\n        'fa-times-circle': toastDetails?.type === 'error',\n        'fa-check-circle': toastDetails?.type === 'success',\n        'fa-exclamation-circle': toastDetails?.type === 'warning',\n        'fa-info-circle': toastDetails?.type === 'info'\n      }\"></i>\n    </div>\n    <div class=\"container-2\">\n      <p>{{ toastDetails?.detail }}</p>\n      <p>{{ toastDetails?.summary }}</p>\n    </div>\n    <button *ngIf=\"show\" id=\"close\" (click)=\"closeToast()\">&times;</button>\n  </div>\n</div> -->\n\n<div class=\"toast-container\" [ngClass]=\"{\n            'toast-top-center': toastDetails?.position === 'tc',\n            'toast-top-left': toastDetails?.position === 'tl',\n            'toast-top-right': toastDetails?.position === 'tr',\n            'toast-bottom-left': toastDetails?.position === 'bl',\n            'toast-bottom-right': toastDetails?.position === 'br',\n            'toast-bottom-center': toastDetails?.position === 'bc'\n          }\" [class.active]=\"show\"\n          [class.toast-top-right]=\"toastDetails?.position === (null || undefined || '')\">\n  <div class=\"ng-toast\" [ngClass]=\"{\n            'error': toastDetails?.type === 'error',\n            'success': toastDetails?.type === 'success',\n            'warning': toastDetails?.type === 'warning',\n            'info': toastDetails?.type === 'info'\n          }\">\n    <div class=\"container-1\">\n      <i class=\"fa\" [ngClass]=\"{\n            'fa-times-circle': toastDetails?.type === 'error',\n            'fa-check-circle': toastDetails?.type === 'success',\n            'fa-exclamation-circle': toastDetails?.type === 'warning',\n            'fa-info-circle': toastDetails?.type === 'info'\n          }\"></i>\n    </div>\n    <div class=\"container-2\">\n      <p>{{ toastDetails?.detail }}</p>\n      <p>{{ toastDetails?.summary }}</p>\n    </div>\n    <button *ngIf=\"show\" id=\"close\" (click)=\"closeToast()\">&times;</button>\n  </div>\n</div>\n", styles: ["*{padding:0;margin:0;box-sizing:border-box;border:none}.show-toast{margin:10px;background-color:#101020;color:#fff;padding:20px;border-radius:5px;cursor:pointer}.fa-times-circle{color:#ff355b}.fa-check-circle{color:#47d764}.fa-exclamation-circle{color:#ffc021}.fa-info-circle{color:#2f86eb}.container-1{margin:7px 0 7px 7px;display:flex}.container-1 i{font-size:30px}.container-2{display:flex;flex-direction:column;margin-left:4px;font-family:roboto,sans-serif}.container-2 p:first-child{display:flex;flex-direction:column;margin-left:5px;font-size:.9rem;font-family:roboto,sans-serif}.container-2 p:last-child{font-size:14px;color:#656565;font-weight:400;font-family:roboto,sans-serif;margin-left:5px}#close{align-self:flex-start;background-color:transparent;font-size:25px;line-height:0;color:#656565;cursor:pointer}.toast-container{pointer-events:none;position:fixed;z-index:999999;transition:.5s}.toast-top-center{top:5%;right:0;width:100%;transform:translateY(-400px)}.toast-top-center.active{transform:translate(0)}.toast-bottom-center{bottom:5%;right:0;width:100%;transform:translateY(400px)}.toast-bottom-center.active{transform:translate(0)}.toast-top-right{right:1%;top:5%;transform:translate(400px)}.toast-top-right.active{transform:translate(0)}.toast-bottom-right{right:1%;bottom:5%;transform:translate(400px)}.toast-bottom-right.active{transform:translate(0)}.toast-top-left{left:1%;top:5%;transform:translate(-400px)}.toast-top-left.active{transform:translate(0)}.toast-bottom-left{left:1%;bottom:5%;transform:translate(-400px)}.toast-bottom-left.active{transform:translate(0)}.toast-container.toast-top-center .ng-toast,.toast-container.toast-bottom-center .ng-toast{width:350px;margin-left:auto;margin-right:auto}.ng-toast{width:350px;height:auto;font-size:1rem;padding:10px;box-shadow:0 10px 20px #4b32320d;border-radius:7px;display:grid;grid-template-columns:1.2fr 6fr .5fr;transition:.5s;pointer-events:auto}.ng-toast.error{border-left:8px solid #ff355b;background-color:#ffe7e6}.ng-toast.warning{border-left:8px solid #ffc021;background-color:#fff2e2}.ng-toast.success{border-left:8px solid #47d764;background-color:#e4f8f0}.ng-toast.info{border-left:8px solid #2f86eb;background-color:#e9e9ff}\n"] }]
        }], ctorParameters: function () { return [{ type: NgToastService }]; } });

class NgToastModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.1", ngImport: i0, type: NgToastModule, declarations: [NgToastComponent], imports: [CommonModule], exports: [NgToastComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.1", ngImport: i0, type: NgToastModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgToastComponent
                    ],
                    imports: [
                        CommonModule,
                    ],
                    exports: [
                        NgToastComponent,
                    ]
                }]
        }] });

/*
 * Public API Surface of ng-toast
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgToastComponent, NgToastModule, NgToastService };
//# sourceMappingURL=ng-angular-popup.mjs.map
